@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aws
 version: 0.13.0
-id: aws-0.13.0-de34023264c951a04f34243645dee6a5
-key: aws_A1gNISTL7y4A0Ii2LV0jZx
+id: aws-0.13.0-9871acc1012a59822ddfb02a5b5cff95
+key: aws_4VYhXuYBlmMCAIk0v0Gcz8
 license: BSD3
 copyright: See contributors list in README and LICENSE file
 maintainer: aristidb@gmail.com
@@ -55,7 +55,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aws-0.13.0
-hs-libraries: HSaws-0.13.0-A1gNISTL7y4A0Ii2LV0jZx
+hs-libraries: HSaws-0.13.0-4VYhXuYBlmMCAIk0v0Gcz8
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
@@ -68,7 +68,7 @@ depends:
     case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
+    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
@@ -91,7 +91,7 @@ depends:
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    xml-conduit-1.3.4-233ad2c214e14cf140bab4070afaa144
+    xml-conduit-1.3.4-2cb0835929c2dc7743cd241414dfd06a
 haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
 haddock-html: /usr/share/doc/haskell-aws/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
